==> birdtray_1.8.0+ds.orig.tar.xz: birdtray-1.8.0/src/translations/installer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>German</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Ein freies Systemleistenbenachrichtigungsprogramm für neue Mails von Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Windows-Integration</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Auswählen, wie ${PRODUCT_NAME} in Windows integriert werden soll.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>${PRODUCT_NAME} automatisch nach dem Anmelden starten.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Aktualisierungsüberprüfung</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Beim Starten von ${PRODUCT_NAME} automatisch nach Aktualisierungen suchen.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Programmgruppeneintrag</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Erstellt eine ${PRODUCT_NAME}-Programmgruppe in der Programmliste des Startmenüs.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Desktop-Verknüpfung</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Erstellt eine ${PRODUCT_NAME} Verknüpfung auf dem Desktop.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Startmenüverknüpfung</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Erstellt eine ${PRODUCT_NAME}-Verknüpfung im Startmenü.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Anzeigesprachen</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Wählen Sie Anzeigesprachen für ${PRODUCT_NAME} aus. ${PRODUCT_NAME} wird eine Sprache basierend auf der Systemsprache auswählen.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME}-Benutzereinstellungen</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Ihre Einstellungen und Konfigurationen in ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Lizenzvereinbarung</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>${PRODUCT_NAME} starten</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>&quot;Deinstallieren&quot; klicken, um den Vorgang zu starten.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Vorherige ${PRODUCT_NAME}-Version wird deinstalliert</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Das Deinstallieren der alten ${PRODUCT_NAME}-Version ist fehlgeschlagen! Wollen Sie fortfahren und ALLES in $3 löschen.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Fehler beim Ausführen des Deinstallationsprogramms.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} wird momentan ausgeführt. Drücken Sie OK, um ${PRODUCT_NAME} anzuhalten und mit der Installation fortzufahren.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Prozess ${EXE_NAME} wird angehalten</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Das Anhalten von ${PRODUCT_NAME} ist fehlgeschlagen. Bitte versuchen Sie es erneut oder schließen Sie ${PRODUCT_NAME} manuell, um mit der Installation fortzufahren.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} wird momentan ausgeführt. Drücken Sie OK, um ${PRODUCT_NAME} anzuhalten und mit der Deinstallation fortzufahren.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Das Anhalten von ${PRODUCT_NAME} ist fehlgeschlagen. Bitte versuchen Sie es erneut oder schließen Sie ${PRODUCT_NAME} manuell, um mit der Deinstallation fortzufahren.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>Das Installationsprogramm von ${PRODUCT_NAME} wird bereits ausgeführt.$\r$\nBitte schließen Sie alle anderen Instanzen und klicken sie &quot;Wiederholen&quot; um fortzufahren, oder &quot;Abbruch&quot; um die Installation abzubrechen.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>Das Denstallationsprogramm von ${PRODUCT_NAME} wird bereits ausgeführt.$\r$\nBitte schließen Sie alle anderen Instanzen und klicken sie &quot;Wiederholen&quot; um fortzufahren, oder &quot;Abbruch&quot; um die Deinstallation abzubrechen.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Der Installationspfad darf keine der folgenden Buchstaben enthalten:$\r$\n${BAD_PATH_CHARS}</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>Im Installationspfad wurde eine vorherig installierte ${PRODUCT_NAME}-Version gefunden, die ersetzt wird.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Der Installationspfad ist nicht leer, aber scheint keine vorherig installierte ${PRODUCT_NAME}-Version zu beinhalten. Der Inhalt des Ordners wird Überschrieben.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (nur für den aktuellen Benutzer)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} konnte nicht komplett installiert werden.$\r$\n\Bitte starten Sie Windows neu und führen Sie das Installationsprogramm erneut aus.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} konnte nicht komplett installiert werden.$\r$\n\Bitte starten Sie Windows neu und führen Sie das Installationsprogramm erneut aus.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} konnte nicht komplett deinstalliert werden.$\r$\n\Bitte starten Sie Windows neu und führen Sie das Deinstallationsprogramm erneut aus.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Fehler beim Löschen der Datei:$\r$\n$\r$\n$0$\r$\n$\r$\nKlicke &quot;Wiederholen&quot;, um es erneut zu versuchen, oder$\r$\n&quot;Abbruch&quot;, um die Deinstallation abzubrechen.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Fehler beim Löschen der Datei $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Sie sind dabei, die 32-Bit-Version von ${PRODUCT_NAME} auf ihrem 64-Bit-Windows zu installieren. Es gibt eine 64-bit-${PRODUCT_NAME}-Version, die heruntergeladen werden kann.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Dieses Installationsprogramm beinhaltet die 64-Bit-Version von ${PRODUCT_NAME}. Auf Ihrem Computer läuft eine 32-Bit-Version von Windows, welche keine 64-Bit-Programme ausführen kann. Bitte laden sie das 32-Bit-Installationsprogramm von ${PRODUCT_NAME} herunter.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Dieses Programm benötigt mindestens Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>Die ${PRODUCT_NAME} Deinstallation wurde abgebrochen. Bitte versuchen Sie es später erneut.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} Einstellungen</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>Das Deinstallationsprogramm wurde mit Administrator-Rechten gestartet, aber es scheint keine ${PRODUCT_NAME}-Installation beim Administrator vorhanden zu sein. Wollen Sie die Deinstallation als Nutzer ohne Administrator-Rechten neustarten?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Öffne $0 im Standardbrowser...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Die Visual C++ Runtime ${ARCH} konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>Die folgende benötigte Komponente wurde auf diesem Computer nicht gefunden:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nWollen Sie das Installationsprogramm für die Komponente herunterladen?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Starten Sie bitte das Installationsprogramm, nachdem es heruntergeladen wurde. Wenn die Installation abgeschlossen ist, klicken Sie bitte auf OK, um den Installationsstatus erneut zu überprüfen.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>Die erforderliche Komponente wurde erfolgreich auf Ihrem Computer gefunden.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>Die erforderliche Komponente konnte nicht auf Ihrem Computer gefunden werden. Bitte suchen Sie Online nach Visual C++ ${ARCH} Downloads für Visual Studio 2015 und höher.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} wird nicht starten können.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} wird nicht starten können, da eine erforderliche Komponente fehlt.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Niederländisch</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italienisch</translation>
    </message>
</context>
</TS>

==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>German</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Ein freies Systemleistenbenachrichtigungsprogramm für neue Mails von Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Windows-Integration</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Auswählen, wie ${PRODUCT_NAME} in Windows integriert werden soll.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>${PRODUCT_NAME} automatisch nach dem Anmelden starten.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Aktualisierungsüberprüfung</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Beim Starten von ${PRODUCT_NAME} automatisch nach Aktualisierungen suchen.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Programmgruppeneintrag</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Erstellt eine ${PRODUCT_NAME}-Programmgruppe in der Programmliste des Startmenüs.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Desktop-Verknüpfung</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Erstellt eine ${PRODUCT_NAME} Verknüpfung auf dem Desktop.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Startmenüverknüpfung</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Erstellt eine ${PRODUCT_NAME}-Verknüpfung im Startmenü.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Anzeigesprachen</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Wählen Sie Anzeigesprachen für ${PRODUCT_NAME} aus. ${PRODUCT_NAME} wird eine Sprache basierend auf der Systemsprache auswählen.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME}-Benutzereinstellungen</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Ihre Einstellungen und Konfigurationen in ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Lizenzvereinbarung</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>${PRODUCT_NAME} starten</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>&quot;Deinstallieren&quot; klicken, um den Vorgang zu starten.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Vorherige ${PRODUCT_NAME}-Version wird deinstalliert</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Das Deinstallieren der alten ${PRODUCT_NAME}-Version ist fehlgeschlagen! Wollen Sie fortfahren und ALLES in $3 löschen.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Fehler beim Ausführen des Deinstallationsprogramms.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} wird momentan ausgeführt. Drücken Sie OK, um ${PRODUCT_NAME} anzuhalten und mit der Installation fortzufahren.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Prozess ${EXE_NAME} wird angehalten</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Das Anhalten von ${PRODUCT_NAME} ist fehlgeschlagen. Bitte versuchen Sie es erneut oder schließen Sie ${PRODUCT_NAME} manuell, um mit der Installation fortzufahren.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} wird momentan ausgeführt. Drücken Sie OK, um ${PRODUCT_NAME} anzuhalten und mit der Deinstallation fortzufahren.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Das Anhalten von ${PRODUCT_NAME} ist fehlgeschlagen. Bitte versuchen Sie es erneut oder schließen Sie ${PRODUCT_NAME} manuell, um mit der Deinstallation fortzufahren.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>Das Installationsprogramm von ${PRODUCT_NAME} wird bereits ausgeführt.$\r$\nBitte schließen Sie alle anderen Instanzen und klicken sie &quot;Wiederholen&quot; um fortzufahren, oder &quot;Abbruch&quot; um die Installation abzubrechen.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>Das Denstallationsprogramm von ${PRODUCT_NAME} wird bereits ausgeführt.$\r$\nBitte schließen Sie alle anderen Instanzen und klicken sie &quot;Wiederholen&quot; um fortzufahren, oder &quot;Abbruch&quot; um die Deinstallation abzubrechen.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Der Installationspfad darf keine der folgenden Buchstaben enthalten:$\r$\n${BAD_PATH_CHARS}</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>Im Installationspfad wurde eine vorherig installierte ${PRODUCT_NAME}-Version gefunden, die ersetzt wird.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Der Installationspfad ist nicht leer, aber scheint keine vorherig installierte ${PRODUCT_NAME}-Version zu beinhalten. Der Inhalt des Ordners wird Überschrieben.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (nur für den aktuellen Benutzer)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} konnte nicht komplett installiert werden.$\r$\n\Bitte starten Sie Windows neu und führen Sie das Installationsprogramm erneut aus.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} konnte nicht komplett installiert werden.$\r$\n\Bitte starten Sie Windows neu und führen Sie das Installationsprogramm erneut aus.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} konnte nicht komplett deinstalliert werden.$\r$\n\Bitte starten Sie Windows neu und führen Sie das Deinstallationsprogramm erneut aus.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Fehler beim Löschen der Datei:$\r$\n$\r$\n$0$\r$\n$\r$\nKlicke &quot;Wiederholen&quot;, um es erneut zu versuchen, oder$\r$\n&quot;Abbruch&quot;, um die Deinstallation abzubrechen.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Fehler beim Löschen der Datei $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Sie sind dabei, die 32-Bit-Version von ${PRODUCT_NAME} auf ihrem 64-Bit-Windows zu installieren. Es gibt eine 64-bit-${PRODUCT_NAME}-Version, die heruntergeladen werden kann.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Dieses Installationsprogramm beinhaltet die 64-Bit-Version von ${PRODUCT_NAME}. Auf Ihrem Computer läuft eine 32-Bit-Version von Windows, welche keine 64-Bit-Programme ausführen kann. Bitte laden sie das 32-Bit-Installationsprogramm von ${PRODUCT_NAME} herunter.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Dieses Programm benötigt mindestens Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>Die ${PRODUCT_NAME} Deinstallation wurde abgebrochen. Bitte versuchen Sie es später erneut.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} Einstellungen</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>Das Deinstallationsprogramm wurde mit Administrator-Rechten gestartet, aber es scheint keine ${PRODUCT_NAME}-Installation beim Administrator vorhanden zu sein. Wollen Sie die Deinstallation als Nutzer ohne Administrator-Rechten neustarten?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Öffne $0 im Standardbrowser...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Die Visual C++ Runtime ${ARCH} konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>Die folgende benötigte Komponente wurde auf diesem Computer nicht gefunden:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nWollen Sie das Installationsprogramm für die Komponente herunterladen?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Starten Sie bitte das Installationsprogramm, nachdem es heruntergeladen wurde. Wenn die Installation abgeschlossen ist, klicken Sie bitte auf OK, um den Installationsstatus erneut zu überprüfen.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>Die erforderliche Komponente wurde erfolgreich auf Ihrem Computer gefunden.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>Die erforderliche Komponente konnte nicht auf Ihrem Computer gefunden werden. Bitte suchen Sie Online nach Visual C++ ${ARCH} Downloads für Visual Studio 2015 und höher.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} wird nicht starten können.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} wird nicht starten können, da eine erforderliche Komponente fehlt.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Niederländisch</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portugiesisch</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Spanisch</translation>
    </message>
</context>
</TS>
